@@ -1,8 +1,8 @@
-from pg_python._db_object import Db
-from pg_python._write import make_postgres_write_statement
-from pg_python._read import make_postgres_read_statement, prepare_values
-from pg_python._update import make_postgres_update_statement
-from pg_python._delete import make_postgres_delete_statement
+from _db_object import Db
+from _write import make_postgres_write_statement
+from _read import make_postgres_read_statement, prepare_values
+from _update import make_postgres_update_statement
+from _delete import make_postgres_delete_statement
 
 
 db = None
@@ -11,8 +11,10 @@ def _get_db():
     global db
     return db
 
-def pg_server(db_name, username, password, host_address):
-  global db
+print_debug_log = True
+params_map = {}
+def pg_server(db_name, username, password, host_address, debug=True):
+  global db, print_debug_log, params_map
   params_map = {
     'dbname': db_name,
     'user': username,
@@ -20,6 +22,7 @@ def pg_server(db_name, username, password, host_address):
     'host': host_address,
     }
   db = Db(params_map)
+  print_debug_log = debug
 
 def write(table, kv_map):
     """
@@ -27,14 +30,16 @@ def write(table, kv_map):
     :param kv_map: Key values.
     :return success_bool:
     """
+    global db, print_debug_log, params_map
     connection = db.get_connection()
     cursor = db.get_cursor()
-    command, values = make_postgres_write_statement(table, kv_map)
+    command, values = make_postgres_write_statement(table, kv_map, print_debug_log)
     try:
         cursor.execute(command, values)
         connection.commit()
     except Exception as e:
         print("Db Cursor Write Error: %s" % e)
+        db = Db(params_map)
         return False
     return True
 
@@ -50,14 +55,14 @@ def read(table, keys_to_get, kv_map, limit=None, order_by=None, order_type=None)
     """
     error_return = None
     cursor = db.get_cursor()
-    command, values = make_postgres_read_statement(table, kv_map, keys_to_get, limit, order_by, order_type)
+    command, values = make_postgres_read_statement(table, kv_map, keys_to_get, limit, order_by, order_type, print_debug_log)
     try:
         cursor.execute(command, values)
         all_values = cursor.fetchall()
         return prepare_values(all_values, keys_to_get)
     except Exception as e:
-        print("Db Cursor Write Error: %s" % e)
-        return False
+        print("Db Cursor Read Error: %s" % e)
+        return []
 
 def update(table, update_kv_map, where_kv_map):
     """
@@ -66,14 +71,16 @@ def update(table, update_kv_map, where_kv_map):
     :param where_kv_map: the kv map to search for values, all values ARE ANDed.
     :return: Success or Failure.
     """
+    global db, print_debug_log, params_map
     connection = db.get_connection()
     cursor = db.get_cursor()
-    command, values = make_postgres_update_statement(table, update_kv_map, where_kv_map)
+    command, values = make_postgres_update_statement(table, update_kv_map, where_kv_map, print_debug_log)
     try:
         cursor.execute(command, values)
         connection.commit()
     except Exception as e:
         print("Db Cursor Update Error: %s" % e)
+        db = Db(params_map)
         return False
     return True
 
@@ -85,13 +92,15 @@ def delete(table, where_kv_map):
     :param where_kv_map: the kv map to search for values, all values ARE ANDed.
     :return: True or False
     """
+    global db, print_debug_log, params_map
     connection = db.get_connection()
     cursor = db.get_cursor()
-    command, values = make_postgres_delete_statement(table, where_kv_map)
+    command, values = make_postgres_delete_statement(table, where_kv_map, print_debug_log)
     try:
         cursor.execute(command, values)
         connection.commit()
     except Exception as e:
         print("Db Cursor Delete Error: %s" % e)
+        db = Db(params_map)
         return False
     return True
